@@ -2,6 +2,6 @@
 from zope.i18nmessageid import MessageFactory
 
 
-PloneMessageFactory = MessageFactory('plone')
+PloneMessageFactory = MessageFactory("plone")
 
 _PMF = PloneMessageFactory
