@@ -29,6 +29,7 @@ from zope.schema.interfaces import IVocabularyFactory
 from zope.schema.vocabulary import SimpleVocabulary
 
 import six
+import copy
 
 
 def uuidToObject(uuid):
@@ -162,19 +163,30 @@ class ExistingContentTile(Tile):
     def content_view(self):
         context = self.content_context
         if context is not None:
-            view_name = self.data.get("view_template") or context.getLayout()
             return api.content.get_view(
-                name=view_name, context=context, request=self.request
+                name=self.content_view_name, context=context, request=self.request
             )
         return None
 
+    @property
+    def content_view_name(self):
+        context = self.content_context
+        if context is not None:
+            view_name = self.data.get("view_template") or context.getLayout()
+            return view_name
+        return ""
+
+    _marker = dict()
+
     @property
     def item_macros(self):
         view = self.content_view
         if view and IBrowserView.providedBy(view):
             # IBrowserView
             if getattr(view, "index", None):
-                return view.index.macros
+                macros = getattr(view.index, "macros", self._marker)
+                if macros is not self._marker:
+                    return view.index.macros
         elif view:
             # FSPageTemplate
             return view.macros
@@ -187,10 +199,10 @@ class ExistingContentTile(Tile):
         if isinstance(html, six.text_type):
             html = html.encode("utf-8")
         serializer = getHTMLSerializer([html], pretty_print=False, encoding="utf-8")
-        panels = dict(
-            (node.attrib["data-panel"], node)
+        panels = [
+            node
             for node in utils.panelXPath(serializer.tree)
-        )
+            ]
         if panels:
             request = self.request.clone()
             request.URL = self.content_context.absolute_url() + "/"
@@ -199,15 +211,25 @@ class ExistingContentTile(Tile):
             except RuntimeError:  # maximum recursion depth exceeded
                 return []
             clear = '<div style="clear: both;"></div>'
-            return [
-                "".join(
-                    [
-                        safe_unicode(serializer.serializer(child))
-                        for child in node.getchildren()
-                    ]
-                )
-                for name, node in panels.items()
-            ] + [clear]
+
+            result = []
+            serializer = serializer.serializer
+            for panel in panels:
+                panel_html = []
+                for child in panel.getchildren():
+                    # lxml element needs to be copied
+                    # to put it out of context of the root tree it comes from.
+                    # If this is not done, serializer will keep on serializing
+                    # after element is closed until last
+                    # element of the root tree.
+                    child_copy = copy.deepcopy(child)
+                    child_html = safe_unicode(serializer(child_copy))
+                    panel_html.append(child_html)
+                panel_html = "".join(panel_html)
+                result.append(panel_html)
+            result.append(clear)
+            return result
+
         return []
 
     @property
@@ -242,32 +264,6 @@ class ExistingContentTile(Tile):
             return css_class
         return " ".join([css_class, additional_classes])
 
-    def __getattr__(self, name):
-        if name == self.id:
-            # We are traversing to this tile, for example via
-            # @@plone.app.standardtiles.existingcontent/3033115c0421469382d4d5297435f1ed
-            # See also Tile.__getitem__.
-            # Note that we are always anonymous at this point.
-            # This caused authorization problems before adding this check.
-            return self
-        # proxy attributes for this view to the selected view of the content
-        # item so views work
-        if (
-            name
-            in (
-                "data",
-                "content_context",
-                "content_view",
-                "item_macros",
-                "item_panels",
-                "getPhysicalPath",
-                "index_html",
-            )
-            or name.startswith(("_", "im_", "func_"))
-        ):
-            return Tile.__getattr__(self, name)
-        return getattr(self.content_view, name)
-
 
 @provider(IVocabularyFactory)
 def availableContentViewsVocabulary(context):
